@@ -27,7 +27,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-commands-file.c 5437 2007-01-09 23:09:57Z pborelli $
+ * $Id: gedit-commands-file.c 5812 2007-08-15 12:19:59Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -134,15 +134,15 @@ load_file_list (GeditWindow         *window,
 	GList         *win_docs;
 	GSList        *uris_to_load = NULL;
 	const GSList  *l;
-	
+
 	gedit_debug (DEBUG_COMMANDS);
 
 	g_return_val_if_fail ((uris != NULL) && (uris->data != NULL), 0);
 
 	win_docs = gedit_window_get_documents (window);
 
-	/* Remove the uris corresponding to documents already open in "window".
-	   Add remove duplicates from "uris" list */
+	/* Remove the uris corresponding to documents already open
+	 * in "window" and remove duplicates from "uris" list */
 	l = uris;
 	while (uris != NULL)
 	{
@@ -155,8 +155,20 @@ load_file_list (GeditWindow         *window,
 				{
 					gedit_window_set_active_tab (window, tab);
 					jump_to = FALSE;
+
+					if (line_pos > 0)
+					{
+						GeditDocument *doc;
+						GeditView *view;
+
+						doc = gedit_tab_get_document (tab);
+						view = gedit_tab_get_view (tab);
+
+						gedit_document_goto_line (doc, line_pos);
+						gedit_view_scroll_to_cursor (view);
+					}
 				}
-				
+
 				++loaded_files;
 			}
 			else
@@ -165,7 +177,7 @@ load_file_list (GeditWindow         *window,
 								uris->data);
 			}
 		}
-				
+
 		uris = g_slist_next (uris);
 	}
 
@@ -173,7 +185,7 @@ load_file_list (GeditWindow         *window,
 
 	if (uris_to_load == NULL)
 		return loaded_files;
-		
+	
 	uris_to_load = g_slist_reverse (uris_to_load);
 	l = uris_to_load;
 
@@ -373,6 +385,9 @@ open_dialog_response_cb (GeditFileChooserDialog *dialog,
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
+	/* Remember the folder we navigated to */
+	 _gedit_window_set_default_path (window, uris->data);
+
 	gedit_commands_load_uris (window,
 				  uris,
 				  encoding,
@@ -404,7 +419,8 @@ _gedit_cmd_file_open (GtkAction   *action,
 		return;
 	}
 
-	open_dialog = gedit_file_chooser_dialog_new (_("Open Files\342\200\246"),
+	/* Translators: "Open Files" is the title of the file chooser window */ 
+	open_dialog = gedit_file_chooser_dialog_new (_("Open Files"),
 						     GTK_WINDOW (window),
 						     GTK_FILE_CHOOSER_ACTION_OPEN,
 						     NULL,
@@ -513,7 +529,7 @@ open_location_dialog_response_cb (GeditOpenLocationDialog *dlg,
 					      _("The entered location is not valid."));
 
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (msg),
-							  _("Please, check that you typed the "
+							  _("Please check that you typed the "
 							    "location correctly and try again."));
 
 		gtk_window_group_add_window (wg, GTK_WINDOW (msg));
@@ -721,6 +737,10 @@ save_dialog_response_cb (GeditFileChooserDialog *dialog,
 
 		g_free (uri_for_display);
 
+		/* let's remember the dir we navigated too,
+		 * even if the saving fails... */
+		 _gedit_window_set_default_path (window, uri);
+
 		_gedit_tab_save_as (tab, uri, encoding);
 	}
 
