@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugins-engine.c 5692 2007-07-07 09:57:48Z pborelli $
+ * $Id: gedit-plugins-engine.c 5764 2007-08-01 12:43:49Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -339,9 +339,16 @@ gedit_plugins_engine_load_dir (const gchar *dir)
 
 			/* Actually, the plugin will be activated when reactivate_all
 			 * will be called for the first time. */
-			info->active = (g_slist_find_custom (active_plugins,
-							     info->location,
-							     (GCompareFunc)strcmp) != NULL);
+			if (g_slist_find_custom (active_plugins,
+						 info->location,
+						 (GCompareFunc)strcmp) != NULL)
+			{
+				info->active = TRUE;
+			}
+			else
+			{
+				info->active = FALSE;
+			}
 
 			gedit_plugins_list = g_list_prepend (gedit_plugins_list, info);
 
