@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.c 5407 2007-01-04 13:30:58Z pborelli $
+ * $Id: gedit-utils.c 5798 2007-08-14 22:30:35Z paolo $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,7 +49,6 @@
 #include <glib/gi18n.h>
 #include <glade/glade-xml.h>
 #include <libgnomevfs/gnome-vfs.h>
-#include <libgnome/gnome-url.h>
 
 #include "gedit-utils.h"
 
@@ -560,7 +559,6 @@ gedit_warning (GtkWindow *parent, const gchar *format, ...)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	g_signal_connect (G_OBJECT (dialog),
 			  "response",
@@ -893,7 +891,7 @@ gedit_utils_activate_url (GtkAboutDialog *about,
 			  const gchar    *url,
 			  gpointer        data)
 {
-	gnome_url_show (url, NULL);
+	gnome_vfs_url_show (url);
 }
 
 static gboolean
@@ -1003,11 +1001,14 @@ gedit_utils_get_glade_widgets (const gchar *filename,
 		label = gtk_label_new (msg);
 
 		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-
+		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+		
 		g_free (filename_markup);
 		g_free (msg_plain);
 		g_free (msg);
 
+		gtk_misc_set_padding (GTK_MISC (label), 5, 5);
+ 		
 		*error_widget = label;
 
 		return FALSE;
@@ -1022,6 +1023,10 @@ gedit_utils_get_glade_widgets (const gchar *filename,
 		*wid = glade_xml_get_widget (gui, name);
 		if (*wid == NULL)
 		{
+			g_warning ("Cannot find widget '%s' inside file '%s'.",
+				   name,
+				   filename);
+				   
 			filename_markup = g_markup_printf_escaped ("<i>%s</i>", filename);
 			msg_plain = g_strdup_printf (
 					_("Unable to find the required widgets inside file %s."),
@@ -1032,11 +1037,14 @@ gedit_utils_get_glade_widgets (const gchar *filename,
 			label = gtk_label_new (msg);
 
 			gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-
+			gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+			
 			g_free (filename_markup);
 			g_free (msg_plain);
 			g_free (msg);
 
+			gtk_misc_set_padding (GTK_MISC (label), 5, 5);
+ 			
 			*error_widget = label;
 
 			ret = FALSE;
@@ -1140,3 +1148,45 @@ gedit_utils_format_uri_for_display (const gchar *uri)
 		return uri_for_display;
 	}
 }
+
+/**
+ * gedit_utils_drop_get_uris:
+ * @selection_data: the #GtkSelectionData from drag_data_received
+ * @info: the info from drag_data_received
+ *
+ * Create a list of valid uri's from a uri-list drop.
+ * 
+ * Return value: a string array which will hold the uris or NULL if there 
+ *		 were no valid uris. g_strfreev should be used when the 
+ *		 string array is no longer used
+ */
+gchar **
+gedit_utils_drop_get_uris (GtkSelectionData *selection_data)
+{
+	gchar **uris;
+	gint i;
+	gint p = 0;
+	gchar **uri_list;
+
+	uris = g_uri_list_extract_uris ((gchar *) selection_data->data);
+	uri_list = g_new0(gchar *, g_strv_length (uris) + 1);
+
+	for (i = 0; uris[i] != NULL; i++)
+	{
+		gchar *uri;
+		
+		uri = gedit_utils_make_canonical_uri_from_shell_arg (uris[i]);
+		
+		/* Silently ignore malformed URI/filename */
+		if (uri != NULL)
+			uri_list[p++] = uri;
+	}
+
+	if (*uri_list == NULL)
+	{
+		g_free(uri_list);
+		return NULL;
+	}
+
+	return uri_list;
+}
